@@ -112,6 +112,8 @@ DEFAULTS = {
     'OIDC_FIRSTNAME_CLAIM': 'given_name',
     # You can also provide a lambda that takes all the claims as argument and return a lastname
     'OIDC_LASTNAME_CLAIM': 'family_name',
+    # Callable (that takes the user and the claims as arguments) to extend user with other potential additional information available in the claims
+    'OIDC_EXTEND_USER': None,
     'OIDC_BLACKLIST_TOKEN_TIMEOUT_SECONDS': 7 * 86400,  # 7 days
     # Only used when using authorization in header:
     #   Authorization: Bearer id_token
